@@ -37,6 +37,7 @@ static char RCSId[] = "$Id: uutraf.c,v 1.0 1996/01/01 16:51:45 david Rel $";
 #include <time.h>
 #include <limits.h>
 #include <math.h>
+#include <errno.h>
 
 #include "uutraf.h"
 
@@ -56,6 +57,8 @@ static struct option const long_options[] =
 char *progname;					 /* name of the program */
 hostentry *hosttab;				 /* linked list of hosts */
 
+extern int errno;
+
 time_t startlogtime, stoplogtime;
 
 void AnalyzeLogfile(char *logfilename, int newsstats)
